#!/bin/sh
#
# $Id: shutdown-linux.sh,v 1.1.1.1 2006/08/28 02:00:00 holger Exp $
#
# Example ZUPS shutdown script for Linux remote hosts.
#
# Usage: shutdown-linux.sh remote.example.com
#
# !!! PLEASE TEST THIS ON THE COMMAND LINE BEFORE USING IT WITH ZUPS !!!

# ----------------------------------------------------------------------
# Configuration:

REMOTE_USER="root"      # remote user executing the shutdown command
LOG_FACILITY="daemon"   # syslog(3) facility
TIMEOUT=600             # timeout (in seconds) for this script

# Please check whether this shutdown command works on your remote systems.  At
# least on Debian >= 3.0, you could add "-P" to the shutdown(8) command line:
REMOTE_CMD="nohup sh -c '/sbin/shutdown -h now >>/var/log/zups-shutdown.log 2>&1'"

# Check the paths (using the command "which ssh pgrep logger mktemp"):
SSH="/usr/bin/ssh -n -T -o StrictHostKeyChecking=no"
PGREP="/usr/bin/pgrep"
LOGGER="/usr/bin/logger"
TMPFILE=`/bin/mktemp -t $ME.XXXXXX`

ME=`basename $0`
PATH="/bin:/usr/bin:/sbin:/usr/sbin"

# ----------------------------------------------------------------------

timeout()
{
	(
		sleep $1
		kill $$ 2>/dev/null
		test $? -eq 0 && echo "$ME: Timed out after $1 seconds." >&2
	) &

	GRANDCHILDS=`$PGREP -P $!`
	trap "kill $! $GRANDCHILDS 2>/dev/null" 0
}

timeout $TIMEOUT

if [ $# -ne 1 ]; then
	echo "usage: $ME <remote.host>" >&2
	exit 1
elif [ "x$1" = "x-h" ]; then
	echo "usage: $ME <remote.host>"
	exit 0
fi

HOST="$1"

$SSH "$REMOTE_USER@$HOST" "$REMOTE_CMD" 2>&1 | tr -d '\r' >$TMPFILE

if [ -n "$LOG_FACILITY" ]; then
	$LOGGER -i -p $LOG_FACILITY.info -t $ME "[INFO] triggered shutdown of $HOST"
	while read LINE; do
		$LOGGER -i -p $LOG_FACILITY.notice -t $ME "[NOTICE] ssh $HOST: $LINE"
	done <$TMPFILE
fi

rm -f $TMPFILE
exit 0
